@@ -1,5 +1,5 @@
 package Locale::Maketext::Extract::Run;
-$Locale::Maketext::Lexicon::Extract::Run::VERSION = '0.33';
+$Locale::Maketext::Lexicon::Extract::Run::VERSION = '0.35';
 
 use strict;
 use vars qw( @ISA @EXPORT_OK );
@@ -70,9 +70,11 @@ sub run {
                wanted => sub {
                    if (-d) {
                        $File::Find::prune
-                           = /^(\.svn|blib|autogen|var|m4|local|CVS)$/;
+                           = /^(\.svn|blib|autogen|var|m4|local|CVS|\.git)$/;
                        return;
                    }
+                   # Only extract from non-binary, normal files
+                   return unless (-f or -s) and -T;
                    return
                        if (/\.po$|\.bak$|~|,D|,B$/i)
                        || (/^[\.#]/);
